@@ -26,21 +26,43 @@ class _Private:
 
 @dataclass(frozen=True)
 class FullPathModule:
+    "Represents a full path module that exist"
     _inner: _Private = field(repr=False, hash=False, compare=False)
     module: str
 
+    @staticmethod
+    def from_raw(raw: str) -> Union[FullPathModule, Exception]:
+        try:
+            module = find_spec(raw)
+            if module is not None:
+                return FullPathModule(_Private(), raw)
+            return ModuleNotFoundError(raw)
+        except ValueError as err:
+            return err
+
+    @classmethod
+    def assert_module(cls, raw: str) -> Union[FullPathModule, NoReturn]:
+        result = cls.from_raw(raw)
+        return _utils.raise_or_value(result)
+
     @property
     def name(self) -> str:
         return self.module.split(".")[-1]
 
     @property
     def parent(self) -> Optional[FullPathModule]:
-        result = ".".join(self.module.split(".")[:-1])
-        return FullPathModule(_Private(), result) if result else None
+        parent = ".".join(self.module.split(".")[:-1])
+        result = self.from_raw(parent)
+        if isinstance(result, Exception):
+            return None
+        return result
 
     def new_child(self, module: str) -> Optional[FullPathModule]:
         joined = ".".join([self.module, module])
-        return FullPathModule(_Private(), joined)
+        result = self.from_raw(joined)
+        if isinstance(result, Exception):
+            return None
+        return result
 
     def assert_child(self, module: str) -> Union[FullPathModule, Exception]:
         result = self.new_child(module)
@@ -53,17 +75,5 @@ class FullPathModule:
             return self.module.startswith(module.module)
         return False
 
-    @staticmethod
-    def from_raw(raw: str) -> Union[FullPathModule, Exception]:
-        module = find_spec(raw)
-        if module is not None:
-            return FullPathModule(_Private(), raw)
-        return ModuleNotFoundError(raw)
-
-    @classmethod
-    def assert_module(cls, raw: str) -> Union[FullPathModule, NoReturn]:
-        result = cls.from_raw(raw)
-        return _utils.raise_or_value(result)
-
     def __repr__(self) -> str:
         return self.module
