@@ -7,6 +7,9 @@ from ._dag_map import (
 from arch_lint import (
     _utils,
 )
+from arch_lint.error import (
+    BrokenArch,
+)
 from arch_lint.graph import (
     FullPathModule,
     ImportGraph,
@@ -15,6 +18,7 @@ from pathlib import (
     Path,
 )
 from typing import (
+    Callable,
     FrozenSet,
     NoReturn,
     Optional,
@@ -51,8 +55,9 @@ def _check_independence(
 ) -> Union[None, NoReturn]:
     result = _independence(graph, modules)
     if result:
-        raise Exception(
-            f"Broken DAG same lvl modules should be independent {result[0].module} -> {result[1].module}"
+        raise BrokenArch(
+            "Broken DAG same lvl modules should be independent "
+            f"{result[0].module} -> {result[1].module}"
         )
     return None
 
@@ -67,8 +72,9 @@ def _check_dag_over_modules(
         importer = _chain[0]
         imported = _chain[1]
         specific = graph.find_shortest_chain(importer, imported)
-        raise Exception(
-            f"Broken DAG with illegal import {importer.module} -> {imported.module} i.e. chain {specific}"
+        raise BrokenArch(
+            "Broken DAG with illegal import "
+            f"{importer.module} -> {imported.module} i.e. chain {specific}"
         )
     return None
 
@@ -80,7 +86,7 @@ def dag_completeness(
     missing = children - dag.all_modules
     if len(children) > 1 and missing:
         relative = ",".join(d.name for d in missing)
-        raise Exception(
+        raise BrokenArch(
             f"Missing children modules of `{parent}` at DAG i.e. {relative}"
         )
     return None
@@ -92,11 +98,11 @@ def dag_completeness_from_set(
     diff = expected - dag.all_modules
     if diff:
         relative = ",".join(d.name for d in diff)
-        raise Exception(f"Missing root modules i.e. {relative}")
+        raise BrokenArch(f"Missing root modules i.e. {relative}")
     diff_2 = dag.all_modules - expected
     if diff_2 and raise_if_excess:
         relative_2 = ",".join(d.name for d in diff_2)
-        raise Exception(f"Not listed modules i.e. {relative_2}")
+        raise BrokenArch(f"Not listed modules i.e. {relative_2}")
     return None
 
 
@@ -105,7 +111,20 @@ def dag_completeness_from_dir(
     dir_path: Path,
     raise_if_excess: bool,
     parent: Optional[FullPathModule],
+    path_filter: Callable[[Path], bool] = lambda _: True,
 ) -> Union[None, NoReturn]:
+    """
+    Check a DAG object completeness taking the elements of
+    `dir_path` as the complete expected list of modules.
+
+    - `dir_path` children are transformed into FullPathModule
+    using children name as the module name.
+    - if `parent` is provided then the FullPathModule object from
+    `dir_path` children will be expected to be children of `parent`
+    - `path_filter` used to filter the children of `dir_path` that
+    will be transformed
+    """
+
     def _to_module(raw: str) -> Union[FullPathModule, Exception]:
         if parent:
             _parent = parent.assert_child(raw)
@@ -114,28 +133,32 @@ def dag_completeness_from_dir(
 
     if dir_path.is_dir():
         expected = _utils.transform_sets(
-            frozenset(p.name for p in dir_path.iterdir()),
+            frozenset(p.name for p in filter(path_filter, dir_path.iterdir())),
             _to_module,
         )
         if isinstance(expected, Exception):
             raise expected
         return dag_completeness_from_set(dag, expected, raise_if_excess)
-    raise Exception("Expected a dir path")
+    raise BrokenArch("Expected a dir path")
 
 
 def dag_map_completeness(
     dag_map: DagMap, graph: ImportGraph, parent: FullPathModule
 ) -> Union[None, NoReturn]:
+    """
+    Check a DagMap object completeness taking the children of
+    `parent` as the complete expected list of modules.
+    """
     parent_dag = dag_map.get(parent)
     children = graph.find_children(parent)
     if not parent_dag and len(children) > 1:
-        raise Exception(f"Missing module at DagMap i.e. {parent}")
+        raise BrokenArch(f"Missing module at DagMap i.e. {parent}")
     if parent_dag:
         dag_completeness(parent_dag, graph, parent)
     for c in children:
         dag = dag_map.get(c)
         if not dag and len(graph.find_children(c)) > 1:
-            raise Exception(f"Missing module at DagMap i.e. {c}")
+            raise BrokenArch(f"Missing module at DagMap i.e. {c}")
         if dag:
             dag_completeness(dag, graph, c)
         dag_map_completeness(dag_map, graph, c)
@@ -146,6 +169,10 @@ def check_dag(
     dag: DAG,
     graph: ImportGraph,
 ) -> Union[None, NoReturn]:
+    """
+    Check a DAG object completeness taking the children of
+    `parent` as the complete expected list of modules.
+    """
     for n, c in enumerate(dag.layers):
         _check_independence(graph, c)
         for lower_modules in dag.layers[n + 1 :]:
