@@ -1,3 +1,6 @@
+from arch_lint.error import (
+    BrokenArch,
+)
 from arch_lint.graph import (
     FullPathModule,
     ImportGraph,
@@ -15,7 +18,12 @@ def unauthorized_imports(
     allowlist: FrozenSet[FullPathModule],
     graph: ImportGraph,
 ) -> FrozenSet[FullPathModule]:
-    return graph.find_modules_that_directly_import(forbidden) - allowlist
+    illegal = graph.find_modules_that_directly_import(forbidden) - allowlist
+
+    def _is_not_parent_of_allowed(module: FullPathModule) -> bool:
+        return not any(module.is_descendant_of(a) for a in allowlist)
+
+    return frozenset(filter(_is_not_parent_of_allowed, illegal))
 
 
 def check_forbidden(
@@ -26,7 +34,8 @@ def check_forbidden(
         illegal = unauthorized_imports(forbidden, allowlist, graph)
         if illegal:
             _illegal = frozenset(i.module for i in illegal)
-            raise Exception(
-                f"Forbidden module `{forbidden.module}` imported by unauthorized modules i.e. {_illegal}"
+            raise BrokenArch(
+                f"Forbidden module `{forbidden.module}` "
+                f"imported by unauthorized modules i.e. {_illegal}"
             )
     return None
