@@ -2,6 +2,9 @@ from __future__ import (
     annotations,
 )
 
+from arch_lint.error import (
+    BrokenArch,
+)
 from arch_lint.graph import (
     FullPathModule,
     ImportGraph,
@@ -24,6 +27,7 @@ class _Private:
 
 @dataclass(frozen=True)
 class PrivateModule:
+    "Represents a private `FullPathModule` i.e. that its name starts with `_`"
     _private: _Private = field(repr=False, hash=False, compare=False)
     module: FullPathModule
 
@@ -61,7 +65,7 @@ def check_private(
 
     for p in private_modules:
         if not _validate_import(p):
-            raise Exception(
+            raise BrokenArch(
                 f"Illegal import of private module {module.module} -> {p.module.module}"
             )
     for c in graph.find_children(module):
