@@ -16,7 +16,7 @@ _dag: Dict[str, Tuple[Union[Tuple[str, ...], str], ...]] = {
         ("dag", "forbidden", "private"),
         "graph",
         "_full_path",
-        "_utils",
+        ("error", "_utils"),
     ),
     "arch_lint.dag": (
         "check",
